@@ -22,12 +22,12 @@
 
 name = "CrunchyFrog"
 appname = name.lower()
-version = "0.3.0"
+version = "0.3.1"
 copyright = "Copyright (C) 2008 Andi Albrecht <albrecht.andi@gmail.com>"
 description = "Database front-end for GNOME"
 author = "Andi Albrecht"
 author_email = "albrecht.andi@gmail.com"
-url = "http://cf.andialbrecht.de"
+url = "http://crunchyfrog.googlecode.com"
 long_description = """CrunchyFrog is a database front-end for the GNOME desktop.
 
 Supported databases
@@ -57,25 +57,29 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>."""
 
-translators="""Launchpad Contributions:
-  Kari Argillander (https://launchpad.net/~kari-argillander)
-  Edwin Dijk (https://launchpad.net/~sitix)
-  Anthony Guéchoum (https://launchpad.net/~athael)
-  Guybrush88 (https://launchpad.net/~erpizzo)
-  Ryutatsu Ishigami (https://launchpad.net/~ai-inside+ubuntu)
-  Luca Livraghi (https://launchpad.net/~luca91)
-  Marion Cisternas Milla (https://launchpad.net/~mcisternas)
-  Christian Olate Opazo (https://launchpad.net/~cristian-olate)
-  Penegal (https://launchpad.net/~penegal)
-  Nicola Piovesan (https://launchpad.net/~piovesannicola)
-  Enrico Rosina (https://launchpad.net/~e-rosina)
-  Xoan Sampaiño (https://launchpad.net/~xoan)
-  Skiros (https://launchpad.net/~magoskiros)
-  Pierre Slamich (https://launchpad.net/~pierre-slamich)
-  Jeppe Toustrup (https://launchpad.net/~tenzer)
-  ubby (https://launchpad.net/~kostas-sytske)
-  Linus C Unneback (https://launchpad.net/~linus-folkdatorn)
-  Yaron (https://launchpad.net/~sh-yaron)
-  Muhammad Zulfikar (https://launchpad.net/~zulfikars)
-  0x00080h (https://launchpad.net/~einstein89)
+translators="""Kari Argillander (https://launchpad.net/~kari-argillander)
+cd (https://launchpad.net/~zadoev)
+Thanos Chatziathanassiou (https://launchpad.net/~tchatzi)
+Edwin Dijk (https://launchpad.net/~sitix)
+Micke Elm (https://launchpad.net/~mickeelm)
+Anthony Guéchoum (https://launchpad.net/~athael)
+Guybrush88 (https://launchpad.net/~erpizzo)
+Ryutatsu Ishigami (https://launchpad.net/~ai-inside+ubuntu)
+Luca Livraghi (https://launchpad.net/~luca91)
+Marion Cisternas Milla (https://launchpad.net/~mcisternas)
+Christian Olate Opazo (https://launchpad.net/~cristian-olate)
+Penegal (https://launchpad.net/~penegal)
+Martin Picek <picek.martin@gnome-cesko.cz>
+Nicola Piovesan (https://launchpad.net/~piovesannicola)
+rcares (https://launchpad.net/~rcares)
+Enrico Rosina (https://launchpad.net/~e-rosina)
+Xoan Sampaiño (https://launchpad.net/~xoan)
+Skiros (https://launchpad.net/~magoskiros)
+Pierre Slamich (https://launchpad.net/~pierre-slamich)
+Jeppe Toustrup (https://launchpad.net/~tenzer)
+ubby (https://launchpad.net/~kostas-sytske)
+Linus C Unneback (https://launchpad.net/~linus-folkdatorn)
+Yaron (https://launchpad.net/~sh-yaron)
+Muhammad Zulfikar (https://launchpad.net/~zulfikars)
+0x00080h (https://launchpad.net/~einstein89)
 """
