@@ -33,6 +33,7 @@ import gnome
 import gnomevfs
 import gobject
 import gtk
+import gtksourceview2
 import pango
 
 from kiwi.ui import dialogs
@@ -157,15 +158,19 @@ class Editor(GladeWidget):
             self._query_timer = None
         self.results.set_query(query)
         if query.failed:
-            msg = _(u'Query failed (%.3f seconds)') % query.execution_time
+            msg = _(u'Query failed (%(sec).3f seconds)')
+            msg = msg % {"sec": query.execution_time}
             type_ = 'error'
         elif query.description:
-            msg = (_(u"Query finished (%.3f seconds, %s rows)")
-                   % (query.execution_time, query.rowcount))
+            msg = (_(u"Query finished (%(sec).3f seconds, %(num)d rows)")
+                   % {"sec": query.execution_time,
+                      "num": query.rowcount})
             type_ = 'info'
         else:
-            msg = _(u"Query finished (%.3f seconds, %s affected rows)")
-            msg = msg % (query.execution_time, query.rowcount)
+            msg = _(u"Query finished (%(sec).3f seconds, "
+                    u"%(num)d affected rows)")
+            msg = msg % {"sec": query.execution_time,
+                         "num": query.rowcount}
             type_ = 'info'
         self.results.add_message(msg, type_, query.path_status)
         if self.connection.handler_is_connected(tag_notice):
@@ -185,15 +190,18 @@ class Editor(GladeWidget):
 
     def close(self):
         """Close editor, displays a confirmation dialog for unsaved files."""
-        dlg = ConfirmSaveDialog(self, [self])
-        resp = dlg.run()
-        if resp == 1:
-            ret = dlg.save_files()
-        elif resp == 2:
-            ret = True
+        if self.contents_changed():
+            dlg = ConfirmSaveDialog(self, [self])
+            resp = dlg.run()
+            if resp == 1:
+                ret = dlg.save_files()
+            elif resp == 2:
+                ret = True
+            else:
+                ret = False
+            dlg.destroy()
         else:
-            ret = False
-        dlg.destroy()
+            ret = True
         if ret:
             if self.get_data("win"):
                 self.get_data("win").destroy()
@@ -451,6 +459,34 @@ class Editor(GladeWidget):
         else:
             return True
 
+    # Printing
+
+    def on_print_paginate(self, operation, context, compositor):
+        if compositor.paginate(context):
+            n_pages = compositor.get_n_pages()
+            operation.set_n_pages(n_pages)
+            return True
+        return False
+
+    def on_print_draw_page(self, operation, context, page_no, compositor):
+        compositor.draw_page(context, page_no)
+
+    def on_end_page(self, operation, context, compositor):
+        pass
+
+    def print_contents(self, preview=False):
+        """Send content of editor to printer."""
+        view = self.textview
+        compositor = gtksourceview2.print_compositor_new_from_view(view)
+        operation = gtk.PrintOperation()
+        operation.connect('paginate', self.on_print_paginate, compositor)
+        operation.connect('draw-page', self.on_print_draw_page, compositor)
+        if preview:
+            action = gtk.PRINT_OPERATION_ACTION_PREVIEW
+        else:
+            action = gtk.PRINT_OPERATION_ACTION_PRINT_DIALOG
+        operation.run(action)
+
 
 class EditorWindow(GladeWidget):
 
