@@ -310,7 +310,9 @@ class PreferencesDialog(GladeWidget):
         self.sync_repo_file()
 
     def on_plugin_folder_show(self, *args):
-        gnome.url_show(cf.USER_PLUGIN_URI)
+        gtk.show_uri(self.widget.get_screen(),
+                     cf.USER_PLUGIN_URI,
+                     gtk.gdk.x11_get_server_time(self.widget.window))
 
     def refresh(self):
         self.refresh_editor()
@@ -376,7 +378,8 @@ class PreferencesDialog(GladeWidget):
                 if plugin.description:
                     lbl += "\n"+plugin.description
                 if plugin.INIT_ERROR:
-                    lbl += '\n<span color="red">ERROR: '+plugin.INIT_ERROR+'</span>'
+                    lbl += '\n<span color="red">'
+                    lbl += _(u'ERROR')+': '+plugin.INIT_ERROR+'</span>'
                 if plugin.icon:
                     ico = it.load_icon(plugin.icon, gtk.ICON_SIZE_LARGE_TOOLBAR, gtk.ICON_LOOKUP_FORCE_SVG)
                 else:
